
.. currentmodule:: sardana

.. _contents: 

========
Contents
========

.. toctree::
   :maxdepth: 2

   users/index
   devel/index
   Glossary <glossary>
   To do <todo>
   History of changes <revision>
   
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
